# v0.0.4 @ Dec 16, 2022

- Update installation instrutions using conda

# v0.0.3 @ Oct 31, 2022

## Initial implementation

- Implemented conditional execution for dropkick and scpred
- Implemented qc_report.html of a QC summary

